@@ -1,14 +1,11 @@
 package Games::Solitaire::BlackHole::Solver;
-
-use warnings;
+$Games::Solitaire::BlackHole::Solver::VERSION = '0.0.4';
 use strict;
+use warnings;
 
 use 5.008;
 
 
-our $VERSION = '0.0.3';
-
-
 1; # End of Games::Solitaire::BlackHole::Solver
 
 __END__
@@ -23,7 +20,7 @@ Games::Solitaire::BlackHole::Solver - A solver for Black Hole Solitaire
 
 =head1 VERSION
 
-version 0.0.3
+version 0.0.4
 
 =head1 SYNOPSIS
 
@@ -43,7 +40,7 @@ More information about Black Hole Solitaire can be found at:
 
 =head1 VERSION
 
-Version 0.0.3
+version 0.0.4
 
 =head1 AUTHOR
 
@@ -128,8 +125,7 @@ This is free software, licensed under:
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-http://rt.cpan.org/NoAuth/Bugs.html?Dist=Games-Solitaire-BlackHole-Solver
-or by email to bug-games-solitaire-blackhole-solver@rt.cpan.org.
+L<https://github.com/shlomif/games-solitaire-blackhole-solver/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
