@@ -1,5 +1,5 @@
 package Games::Solitaire::BlackHole::Solver::App;
-
+$Games::Solitaire::BlackHole::Solver::App::VERSION = '0.0.4';
 use strict;
 use warnings;
 
@@ -9,9 +9,6 @@ use Getopt::Long;
 use Pod::Usage;
 
 
-our $VERSION = '0.0.3';
-
-
 sub new
 {
     my $class = shift;
@@ -65,7 +62,7 @@ sub run
 
     if ($version)
     {
-        print "black-hole-solve version $VERSION\n";
+        print "black-hole-solve version $Games::Solitaire::BlackHole::Solver::App::VERSION\n";
         exit(0);
     }
 
@@ -211,7 +208,7 @@ implemented as a class to solve the Black Hole solitaire.
 
 =head1 VERSION
 
-version 0.0.3
+version 0.0.4
 
 =head1 SYNOPSIS
 
@@ -280,7 +277,7 @@ More information about Black Hole Solitaire can be found at:
 
 =head1 VERSION
 
-Version 0.0.3
+version 0.0.4
 
 =head1 METHODS
 
@@ -351,8 +348,7 @@ This is free software, licensed under:
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-http://rt.cpan.org/NoAuth/Bugs.html?Dist=Games-Solitaire-BlackHole-Solver
-or by email to bug-games-solitaire-blackhole-solver@rt.cpan.org.
+L<https://github.com/shlomif/games-solitaire-blackhole-solver/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
